from ....tl.mtproto_request import MTProtoRequest
from ....utils import get_input_user, get_input_channel


class InviteToChannelRequest(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. TL definition below.
    channels.inviteToChannel#199f3a6c channel:InputChannel users:Vector<InputUser> = Updates"""

    # Telegram's constructor (U)ID for this class
    constructor_id = 0x199f3a6c
    # Also the ID of its resulting type for fast checks
    subclass_of_id = 0x8af52aac

    def __init__(self, channel, users):
        """
        :param channel: Telegram type: "InputChannel".
        :param users: Telegram type: "InputUser". Must be a list.

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.confirmed = True  # Confirmed by default

        self.channel = get_input_channel(channel)
        self.users = [get_input_user(_x) for _x in users]

    def to_dict(self):
        return {
            'channel': None if self.channel is None else self.channel.to_dict(),
            'users': [] if self.users is None else [None if x is None else x.to_dict() for x in self.users],
        }

    def on_send(self, writer):
        writer.write_int(InviteToChannelRequest.constructor_id, signed=False)
        self.channel.on_send(writer)
        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for _x in self.users:
            _x.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (attributes=None)"""
        return InviteToChannelRequest(None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'channels.inviteToChannel#199f3a6c channel:InputChannel users:Vector<InputUser> = Updates'

    def __str__(self):
        return MTProtoRequest.pretty_format(self)

    def stringify(self):
        return MTProtoRequest.pretty_format(self, indent=0)
