from ....tl.mtproto_request import MTProtoRequest


class BotResults(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. TL definition below.
    messages.botResults#ccd3563d flags:# gallery:flags.0?true query_id:long next_offset:flags.1?string switch_pm:flags.2?InlineBotSwitchPM results:Vector<BotInlineResult> cache_time:int = messages.BotResults"""

    # Telegram's constructor (U)ID for this class
    constructor_id = 0xccd3563d
    # Also the ID of its resulting type for fast checks
    subclass_of_id = 0x3ed4d9c9

    def __init__(self, query_id, results, cache_time, gallery=None, next_offset=None, switch_pm=None):
        """
        :param gallery: Telegram type: "true".
        :param query_id: Telegram type: "long".
        :param next_offset: Telegram type: "string".
        :param switch_pm: Telegram type: "InlineBotSwitchPM".
        :param results: Telegram type: "BotInlineResult". Must be a list.
        :param cache_time: Telegram type: "int".

        Constructor for messages.BotResults: Instance of BotResults.
        """
        super().__init__()

        self.gallery = gallery
        self.query_id = query_id
        self.next_offset = next_offset
        self.switch_pm = switch_pm
        self.results = results
        self.cache_time = cache_time

    def to_dict(self):
        return {
            'gallery': self.gallery,
            'query_id': self.query_id,
            'next_offset': self.next_offset,
            'switch_pm': None if self.switch_pm is None else self.switch_pm.to_dict(),
            'results': [] if self.results is None else [None if x is None else x.to_dict() for x in self.results],
            'cache_time': self.cache_time,
        }

    def on_send(self, writer):
        writer.write_int(BotResults.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.gallery else 0
        flags |= (1 << 1) if self.next_offset else 0
        flags |= (1 << 2) if self.switch_pm else 0
        writer.write_int(flags)

        writer.write_long(self.query_id)
        if self.next_offset:
            writer.tgwrite_string(self.next_offset)

        if self.switch_pm:
            self.switch_pm.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.results))
        for _x in self.results:
            _x.on_send(writer)

        writer.write_int(self.cache_time)

    @staticmethod
    def empty():
        """Returns an "empty" instance (attributes=None)"""
        return BotResults(None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.gallery = True  # Arbitrary not-None value, no need to read since it is a flag

        self.query_id = reader.read_long()
        if (flags & (1 << 1)) != 0:
            self.next_offset = reader.tgread_string()

        if (flags & (1 << 2)) != 0:
            self.switch_pm = reader.tgread_object()

        reader.read_int()  # Vector's constructor ID
        self.results = []  # Initialize an empty list
        _len = reader.read_int()
        for _ in range(_len):
            _x = reader.tgread_object()
            self.results.append(_x)

        self.cache_time = reader.read_int()

    def __repr__(self):
        return 'messages.botResults#ccd3563d flags:# gallery:flags.0?true query_id:long next_offset:flags.1?string switch_pm:flags.2?InlineBotSwitchPM results:Vector<BotInlineResult> cache_time:int = messages.BotResults'

    def __str__(self):
        return MTProtoRequest.pretty_format(self)

    def stringify(self):
        return MTProtoRequest.pretty_format(self, indent=0)
